package org.mmga.clubs.service;

import org.mmga.clubs.dao.AuthDao;
import org.mmga.clubs.dao.AuthPermissionDao;
import org.mmga.clubs.entities.auth.Auth;
import org.mmga.clubs.entities.auth.AuthVo;
import org.mmga.clubs.entities.permission.Permission;
import org.mmga.clubs.entities.permission.PermissionVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class AuthService {
    private final AuthDao authDao;
    private final AuthPermissionDao authPermissionDao;
    private final PermissionService permissionService;
    @Autowired
    public AuthService(AuthDao authDao, AuthPermissionDao authPermissionDao, PermissionService permissionService) {
        this.authDao = authDao;
        this.authPermissionDao = authPermissionDao;
        this.permissionService = permissionService;
    }

    public Auth getAuthById(int auth) {
        AuthVo authVo = this.authDao.getAuthById(auth);
        List<PermissionVo> permissionVos = this.authPermissionDao.getAllPermissionByAuthId(auth);
        List<Permission> permissions = permissionVos.stream().map(permissionService::packagePermission).toList();
        return new Auth(authVo.id(), authVo.name(), permissions);
    }

    public boolean authHasPermission(int authId, int permissionId) {
        return authPermissionDao.countAuthPermission(authId, permissionId) > 0;
    }
}
