package org.mmga.clubs.utils;

import com.auth0.jwt.JWT;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTVerificationException;
import com.auth0.jwt.interfaces.DecodedJWT;
import lombok.extern.slf4j.Slf4j;
import org.mmga.clubs.entities.user.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.security.interfaces.ECPrivateKey;
import java.security.interfaces.ECPublicKey;

@Component
@Slf4j
public class JwtUtils {
    private final ECPublicKey ecPublicKey;
    private final ECPrivateKey ecPrivateKey;
    @Autowired
    public JwtUtils(ECPublicKey ecPublicKey, ECPrivateKey ecPrivateKey){
        this.ecPublicKey = ecPublicKey;
        this.ecPrivateKey = ecPrivateKey;
    }
    public String createToken(User user){
        String jwt = JWT.create().withClaim("uid", user.getId()).sign(Algorithm.ECDSA512(ecPublicKey, ecPrivateKey));
        log.debug("对用户：{}，生成JWT：{}", user.getName(), jwt);
        return jwt;
    }
    public Integer verifyToken(String token) throws JWTVerificationException {
        DecodedJWT verify = JWT.require(Algorithm.ECDSA512(ecPublicKey, ecPrivateKey)).build().verify(token);
        return verify.getClaim("uid").asInt();
    }
}
